{% if prepend %}
    {% if append %}
        <div class="input-prepend input-append">
            <span class="add-on">{{ prepend }}</span>{% include "reform/field.html" %}<span class="add-on">{{ append }}</span>
        </div>
    {% else %}
        <div class="input-prepend">
            <span class="add-on">{{ prepend }}</span>{% include "reform/field.html" %}
        </div>
    {% endif %}
{% else %}
    {% if append %}
        <div class="input-append">
            {% include "reform/field.html" %}<span class="add-on">{{ append }}</span>
        </div>
    {% else %}
        {% include "reform/field.html" %}
    {% endif %}
{% endif %}
