{% load reform widget_tweaks %}

{% with field_type=field|get_form_field_type %}

    {% if field_type == 'DateField' %}
        {% render_field field type="date" %}

    {% elif field_type == 'DateTimeField' %}
        {% render_field field type="datetime-local" %}

    {% elif field_type == 'TimeField' %}
        {% render_field field type="time" %}

    {% elif field_type == 'IntegerField' or field_type == 'DecimalField' %}
        {% render_field field type="number" %}

    {% elif field_type == 'EmailField' %}
        {% render_field field type="email" %}

    {% elif field_type == 'URLField' %}
        {% render_field field type="url" %}

    {% else %}
        {{ field }}

    {% endif %}

{% endwith %}
